% if report.return_sales:

#### ${ _("Return Sales") }

${ _("Code") } | ${ _("Sales Person") } | ${ _("Client") } | ${ _("Return Date") } | ${ _("Sale Value") }
% for sale in report.return_sales:
${ sale.identifier } | ${ sale.salesperson } | ${ sale.client } | ${ format_date(sale.return_date) } | ${ format_price(sale.value) }
${ _("Code") } | ${ _("Method") } | ${ _("Description") } | ${ _("Payment Value") }
% for sale_payment in report.return_sales[sale]:
${ sale_payment.identifier } | ${ sale_payment.method.get_description()} | ${ sale_payment.description } | ${ format_price(sale_payment.value) }
% endfor
% endfor

% endif